@@ -54,24 +54,37 @@ class InjectedComponent:
   def __init__(self, app):
     self._app = app
 
-  def build_node(self, name, idn, input_stream_1, additional_inputs, outputs, output_format):
-    self._name = name if name else "component_"+Counter.get()
-    self._id = str(idn)
-    self._type = "component"
-    self._consumes = [input_stream_1]
+  def build_node(self, **kwargs):
 
+    name = kwargs.pop("name", None)
+    if name:
+      self._name = name 
+    else:
+      self._name = "component_"+Counter.get()
+    self._type = "component"
+    self._id = kwargs.pop("component_id", None)
+
+    self._output_format = kwargs.pop("output_format", "replace")
+
+    input_stream_1 = kwargs.pop("input_stream", None)
+    if input_stream_1:
+      self._consumes = [input_stream_1]
+    else:
+      self._consumes = []
+
+    additional_inputs = kwargs.pop("additional_inputs", None)
     if isinstance(additional_inputs, list):
       self._consumes += additional_inputs
     elif additional_inputs != None:
       self._consumes.append(additional_inputs)
 
+    outputs = kwargs.pop("outputs", None)
     if outputs == None:
       outputs = ["stream_"+Counter.get()]
     elif isinstance(outputs, basestring):
       outputs = [outputs]
     self._emits = outputs
 
-    self._output_format = output_format
 
     Helper.check_name("component", self._name, self._app._names)
     Helper.check_call_component(self)
